==> gnu-ghostscript-8.64.0.tar.bz2: gnu-ghostscript-8.64.0/psi/dwsetup.h <==
/* Copyright (C) 2001-2008 Artifex Software, Inc.
   All Rights Reserved.
  
  This file is part of GNU ghostscript

  GNU ghostscript is free software; you can redistribute it and/or
  modify it under the terms of the version 2 of the GNU General Public
  License as published by the Free Software Foundation.

  GNU ghostscript is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with
  ghostscript; see the file COPYING. If not, write to the Free Software Foundation,
  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

*/


// $Id: dwsetup.h,v 1.9 2009/04/19 13:54:25 Arabidopsis Exp $

#ifndef dwsetup_INCLUDED
#  define dwsetup_INCLUDED

// Definitions for Ghostscript setup program

#ifndef IDC_STATIC
#define IDC_STATIC			-1
#endif

#define IDD_TEXTWIN                     101
#define IDD_DIRDLG                      102
#define IDR_MAIN                        200
#define IDD_MAIN                        201
#define IDC_TARGET_DIR                  202
#define IDC_TARGET_GROUP                203
#define IDC_BROWSE_DIR                  204
#define IDC_BROWSE_GROUP                205
#define IDC_README                      206
#define IDS_APPNAME                     501
#define IDS_TARGET_DIR                  502
#define IDS_TARGET_GROUP                503
#define IDC_PRODUCT_NAME                1000
#define IDC_TEXTWIN_MLE                 1002
#define IDC_TEXTWIN_COPY                1003
#define IDC_INSTALL                     1004
#define IDC_FILES                       1006
#define IDC_FOLDER                      1007
#define IDC_TARGET                      1008
#define IDC_ALLUSERS                    1009
#define IDC_COPYRIGHT                   1010
#define IDC_CJK_FONTS			1011


#endif /* dwsetup_INCLUDED */

==> gnu-ghostscript-8.71.1.tar.bz2: gnu-ghostscript-8.71.1/psi/dwsetup.h <==
/* Copyright (C) 2001-2008 Artifex Software, Inc.
   All Rights Reserved.
  
   This software is provided AS-IS with no warranty, either express or
   implied.

   This software is distributed under license and may not be copied, modified
   or distributed except as expressly authorized under the terms of that
   license.  Refer to licensing information at http://www.artifex.com/
   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
*/


// $Id: dwsetup.h,v 1.2 2010/07/10 22:02:42 Arabidopsis Exp $

#ifndef dwsetup_INCLUDED
#  define dwsetup_INCLUDED

// Definitions for Ghostscript setup program

#ifndef IDC_STATIC
#define IDC_STATIC			-1
#endif

#define IDD_TEXTWIN                     101
#define IDD_DIRDLG                      102
#define IDR_MAIN                        200
#define IDD_MAIN                        201
#define IDC_TARGET_DIR                  202
#define IDC_TARGET_GROUP                203
#define IDC_BROWSE_DIR                  204
#define IDC_BROWSE_GROUP                205
#define IDC_README                      206
#define IDS_APPNAME                     501
#define IDS_TARGET_DIR                  502
#define IDS_TARGET_GROUP                503
#define IDC_PRODUCT_NAME                1000
#define IDC_TEXTWIN_MLE                 1002
#define IDC_TEXTWIN_COPY                1003
#define IDC_INSTALL                     1004
#define IDC_FILES                       1006
#define IDC_FOLDER                      1007
#define IDC_TARGET                      1008
#define IDC_ALLUSERS                    1009
#define IDC_COPYRIGHT                   1010
#define IDC_CJK_FONTS			1011


#endif /* dwsetup_INCLUDED */
